<?php
/**
 * @package     Joomla.UnitTest
 * @subpackage  com_finder
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

require_once JPATH_ADMINISTRATOR . '/components/com_finder/helpers/indexer/helper.php';

/**
 * Test class for FinderIndexerHelper.
 * Generated by PHPUnit on 2012-06-10 at 14:41:01.
 */
class FinderIndexerHelperTest extends TestCaseDatabase
{
	/**
	 * Gets the data set to be loaded into the database during setup
	 *
	 * @return  PHPUnit_Extensions_Database_DataSet_CsvDataSet
	 *
	 * @since   3.1
	 */
	protected function getDataSet()
	{
		$dataSet = new PHPUnit_Extensions_Database_DataSet_CsvDataSet(',', "'", '\\');

		$dataSet->addTable('jos_extensions', JPATH_TEST_DATABASE . '/jos_extensions.csv');
		$dataSet->addTable('jos_finder_terms_common', JPATH_TEST_DATABASE . '/jos_finder_terms_common.csv');
		$dataSet->addTable('jos_finder_types', JPATH_TEST_DATABASE . '/jos_finder_types.csv');

		return $dataSet;
	}

	/**
	 * Tests the parse method
	 *
	 * @return  void
	 *
	 * @since   3.0
	 */
	public function testParse()
	{
		$this->assertThat(
			FinderIndexerHelper::parse('Test string to parse with the txt parser', 'txt'),
			$this->stringContains('Test string to parse with the txt parser'),
			'Tests that FinderIndexerHelper::parse() returns the string given with the txt parser.'
		);
	}

	/**
	 * @todo   Implement testTokenize().
	 */
	public function testTokenize()
	{
		// Remove the following lines when you implement this test.
		$this->markTestIncomplete('This test has not been implemented yet.'
		);
	}

	/**
	 * @todo   Implement testStem().
	 */
	public function testStem()
	{
		$this->assertEquals(
			FinderIndexerHelper::stem('token', 'en'),
			'token'
		);
	}

	/**
	 * Tests the addContentType method
	 *
	 * @return  void
	 *
	 * @since   3.1
	 */
	public function testAddContentType()
	{
		$this->assertThat(
			FinderIndexerHelper::addContentType('Article'),
			$this->equalTo('4'),
			'Tests that addContentType returns the ID for an already existing type.'
		);

		$existingIds = array('1', '2', '3', '4', '5', '6');
		$newTypeId   = FinderIndexerHelper::addContentType('PHPUnit');

		$this->assertFalse(
			in_array($newTypeId, $existingIds),
			'Tests that the new ID does not already exist in the database.'
		);
	}

	/**
	 * Tests the isCommon method
	 *
	 * @return  void
	 *
	 * @since   3.1
	 */
	public function testIsCommon()
	{
		$this->assertTrue(
			FinderIndexerHelper::isCommon('the', 'en'),
			'Tests that FinderIndexerHelper::isCommon() returns true for a common term.'
		);

		$this->assertFalse(
			FinderIndexerHelper::isCommon('joomla', 'en'),
			'Tests that FinderIndexerHelper::isCommon() returns false for an uncommon term.'
		);
	}

	/**
	 * Tests the getDefaultLanguage method
	 *
	 * @return  void
	 *
	 * @since   3.0
	 */
	public function testGetDefaultLanguage()
	{
		$this->assertThat(
			FinderIndexerHelper::getDefaultLanguage(),
			$this->StringContains('en-GB'),
			'The default language is en-GB'
		);
	}

	/**
	 * Tests the getPrimaryLanguage method
	 *
	 * @return  void
	 *
	 * @since   3.0
	 */
	public function testGetPrimaryLanguage()
	{
		$this->assertThat(
			FinderIndexerHelper::getPrimaryLanguage('en-GB'),
			$this->StringContains('en'),
			'The primary language is en'
		);
	}

	/**
	 * @todo   Implement testGetContentPath().
	 */
	public function testGetContentPath()
	{
		// Remove the following lines when you implement this test.
		$this->markTestIncomplete('This test has not been implemented yet.');
	}

	/**
	 * @todo   Implement testGetContentExtras().
	 */
	public function testGetContentExtras()
	{
		// Remove the following lines when you implement this test.
		$this->markTestIncomplete('This test has not been implemented yet.');
	}

	/**
	 * @todo   Implement testPrepareContent().
	 */
	public function testPrepareContent()
	{
		// Remove the following lines when you implement this test.
		$this->markTestIncomplete('This test has not been implemented yet.');
	}
}
