<?php
/**
 * @package     Joomla.UnitTest
 * @subpackage  Archive
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

require_once __DIR__ . '/JArchiveTestCase.php';

/**
 * Test class for JArchiveZip.
 * Generated by PHPUnit on 2011-10-26 at 19:34:31.
 *
 * @package     Joomla.UnitTest
 * @subpackage  Archive
 * @since       11.1
 */
class JArchiveZipTest extends JArchiveTestCase
{
	/**
	 * @var JArchiveZip
	 */
	protected $object;

	/**
	 * Sets up the fixture, for example, opens a network connection.
	 * This method is called before a test is executed.
	 *
	 * @return void
	 */
	protected function setUp()
	{
		parent::setUp();

		$this->object = new JArchiveZip;
	}

	/**
	 * Test...
	 *
	 * @todo Implement testCreate().
	 *
	 * @return void
	 */
	public function testCreate()
	{
		// Remove the following lines when you implement this test.
		$this->markTestIncomplete(
			'This test has not been implemented yet.'
		);
	}

	/**
	 * Tests the extractNative Method.
	 *
	 * @return  void
	 */
	public function testExtractNative()
	{
		if (!JArchiveZip::hasNativeSupport())
		{
			$this->markTestSkipped(
				'ZIP files can not be extracted nativly.'
			);

			return;
		}

		TestReflection::invoke($this->object, 'extractNative', __DIR__ . '/logo.zip', static::$outputPath);
		$this->assertTrue(is_file(static::$outputPath . '/logo-zip.png'));

		if (is_file(static::$outputPath . '/logo-zip.png'))
		{
			unlink(static::$outputPath . '/logo-zip.png');
		}
	}

	/**
	 * Tests the extractCustom Method.
	 *
	 * @return  void
	 */
	public function testExtractCustom()
	{
		if (!JArchiveZip::isSupported())
		{
			$this->markTestSkipped(
				'ZIP files can not be extracted.'
			);

			return;
		}

		TestReflection::invoke($this->object, 'extractCustom', __DIR__ . '/logo.zip', static::$outputPath);
		$this->assertTrue(is_file(static::$outputPath . '/logo-zip.png'));

		if (is_file(static::$outputPath . '/logo-zip.png'))
		{
			unlink(static::$outputPath . '/logo-zip.png');
		}
	}

	/**
	 * Tests the extract Method.
	 *
	 * @return  void
	 */
	public function testExtract()
	{
		if (!JArchiveZip::isSupported())
		{
			$this->markTestSkipped(
				'ZIP files can not be extracted.'
			);

			return;
		}

		$this->object->extract(__DIR__ . '/logo.zip', static::$outputPath);
		$this->assertTrue(is_file(static::$outputPath . '/logo-zip.png'));

		if (is_file(static::$outputPath . '/logo-zip.png'))
		{
			unlink(static::$outputPath . '/logo-zip.png');
		}
	}

	/**
	 * Tests the hasNativeSupport Method.
	 *
	 * @return  void
	 */
	public function testHasNativeSupport()
	{
		$this->assertEquals(
			(function_exists('zip_open') && function_exists('zip_read')),
			JArchiveZip::hasNativeSupport()
		);
	}

	/**
	 * Tests the isSupported Method.
	 *
	 * @return   void
	 *
	 * @depends  testHasNativeSupport
	 */
	public function testIsSupported()
	{
		$this->assertEquals(
			(JArchiveZip::hasNativeSupport() || extension_loaded('zlib')),
			JArchiveZip::isSupported()
		);
	}

	/**
	 * Test...
	 *
	 * @return void
	 */
	public function testCheckZipData()
	{
		$dataZip = file_get_contents(__DIR__ . '/logo.zip');
		$this->assertTrue(
			$this->object->checkZipData($dataZip)
		);

		$dataTar = file_get_contents(__DIR__ . '/logo.tar');
		$this->assertFalse(
			$this->object->checkZipData($dataTar)
		);
	}
}
