<?php
/**
 * @package     Joomla.UnitTest
 * @subpackage  String
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

/**
 * Test class for JStringPunycode.
 * Generated by PHPUnit_SkeletonGenerator 1.2.1 on 2013-12-14 at 11:47:16.
 *
 * @package     Joomla.UnitTest
 * @subpackage  String
 * @since       3.2
 */
class JStringPunycodeTest extends PHPUnit_Framework_TestCase
{
	/**
	 * Tests JStringPunycode::toPunycode
	 *
	 * @return  void
	 *
	 * @since   3.2
	 */
	public function testToPunycode()
	{
		$this->assertEquals(
			JStringPunycode::toPunycode('http://www.джумла-тест.рф'),
			'http://www.xn----7sblgc4ag8bhcd.xn--p1ai',
			'Tests idna_convert encoding a UTF8 url in Cyrillic'
		);

		$this->assertEquals(
			JStringPunycode::toPunycode('http://au-gré-de-nos-plumes.fr'),
			'http://xn--au-gr-de-nos-plumes-fzb.fr',
			'Tests idna_convert encoding a UTF8 url in French'
		);
	}

	/**
	 * Tests JStringPunycode::fromPunycode
	 *
	 * @return  void
	 *
	 * @since   3.2
	 */
	public function testFromPunycode()
	{
		$this->assertEquals(
			JStringPunycode::fromPunycode('http://www.xn----7sblgc4ag8bhcd.xn--p1ai'),
			'http://www.джумла-тест.рф',
			'Tests idna_convert decoding a UTF8 url in Cyrillic'
		);

		$this->assertEquals(
			JStringPunycode::fromPunycode('http://xn--au-gr-de-nos-plumes-fzb.fr'),
			'http://au-gré-de-nos-plumes.fr',
			'Tests idna_convert decoding a UTF8 url in French'
		);
	}

	/**
	 * Tests JStringPunycode::urlToPunycode
	 *
	 * @return  void
	 *
	 * @since   3.2
	 */
	public function testUrlToPunycode()
	{
		$this->assertEquals(
			JStringPunycode::urlToPunycode('http://www.джумла-тест.рф'),
			'http://www.xn----7sblgc4ag8bhcd.xn--p1ai',
			'Tests punycode encoding a UTF8 url in Cyrillic'
		);

		$this->assertEquals(
			JStringPunycode::urlToPunycode('http://au-gré-de-nos-plumes.fr'),
			'http://xn--au-gr-de-nos-plumes-fzb.fr',
			'Tests punycode encoding a UTF8 url in French'
		);
	}

	/**
	 * Tests JStringPunycode::urlToUTF8
	 *
	 * @return  void
	 *
	 * @since   3.2
	 */
	public function testUrlToUTF8()
	{
		$this->assertEquals(
			JStringPunycode::urlToUTF8('http://www.xn----7sblgc4ag8bhcd.xn--p1ai'),
			'http://www.джумла-тест.рф',
			'Tests punycode decoding a UTF8 url in Cyrillic'
		);

		$this->assertEquals(
			JStringPunycode::urlToUTF8('http://xn--au-gr-de-nos-plumes-fzb.fr'),
			'http://au-gré-de-nos-plumes.fr',
			'Tests punycode decoding a UTF8 url in French'
		);
	}

	/**
	 * Tests JStringPunycode::emailToPunycode
	 *
	 * @return  void
	 *
	 * @since   3.2
	 */
	public function testEmailToPunycode()
	{
		$this->assertEquals(
			JStringPunycode::emailToPunycode('example@джумла-тест.рф'),
			'example@xn----7sblgc4ag8bhcd.xn--p1ai',
			'Tests punycode encoding a UTF8 email in Cyrillic'
		);

		$this->assertEquals(
			JStringPunycode::emailToPunycode('example@au-gré-de-nos-plumes.fr'),
			'example@xn--au-gr-de-nos-plumes-fzb.fr',
			'Tests punycode encoding a UTF8 email in French'
		);
	}

	/**
	 * Tests JStringPunycode::emailToUTF8
	 *
	 * @return  void
	 *
	 * @since   3.2
	 */
	public function testEmailToUTF8()
	{
		$this->assertEquals(
			JStringPunycode::emailToUTF8('example@xn----7sblgc4ag8bhcd.xn--p1ai'),
			'example@джумла-тест.рф',
			'Tests punycode decoding a UTF8 email in Cyrillic'
		);

		$this->assertEquals(
			JStringPunycode::emailToUTF8('example@xn--au-gr-de-nos-plumes-fzb.fr'),
			'example@au-gré-de-nos-plumes.fr',
			'Tests punycode decoding a UTF8 email in French'
		);
	}
}
